package androidx.core.graphics.drawable;

import android.content.Context;
import android.content.res.ColorStateList;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.Shader;
import android.graphics.drawable.AdaptiveIconDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.Icon;
import android.net.Uri;
import android.os.Build;
import android.os.Parcelable;
import android.text.TextUtils;
import android.util.Log;
import androidx.versionedparcelable.CustomVersionedParcelable;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.lang.reflect.InvocationTargetException;
import java.nio.charset.Charset;
/* loaded from: classes.dex */
public class IconCompat extends CustomVersionedParcelable {

    /* renamed from: k  reason: collision with root package name */
    static final PorterDuff.Mode f1514k = PorterDuff.Mode.SRC_IN;

    /* renamed from: b  reason: collision with root package name */
    Object f1516b;

    /* renamed from: j  reason: collision with root package name */
    public String f1524j;

    /* renamed from: a  reason: collision with root package name */
    public int f1515a = -1;

    /* renamed from: c  reason: collision with root package name */
    public byte[] f1517c = null;

    /* renamed from: d  reason: collision with root package name */
    public Parcelable f1518d = null;

    /* renamed from: e  reason: collision with root package name */
    public int f1519e = 0;

    /* renamed from: f  reason: collision with root package name */
    public int f1520f = 0;

    /* renamed from: g  reason: collision with root package name */
    public ColorStateList f1521g = null;

    /* renamed from: h  reason: collision with root package name */
    PorterDuff.Mode f1522h = f1514k;

    /* renamed from: i  reason: collision with root package name */
    public String f1523i = null;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class a {
        static int a(Object obj) {
            if (Build.VERSION.SDK_INT >= 28) {
                return c.a(obj);
            }
            try {
                return ((Integer) obj.getClass().getMethod("getResId", new Class[0]).invoke(obj, new Object[0])).intValue();
            } catch (IllegalAccessException e3) {
                Log.e("IconCompat", "Unable to get icon resource", e3);
                return 0;
            } catch (NoSuchMethodException e4) {
                Log.e("IconCompat", "Unable to get icon resource", e4);
                return 0;
            } catch (InvocationTargetException e5) {
                Log.e("IconCompat", "Unable to get icon resource", e5);
                return 0;
            }
        }

        static String b(Object obj) {
            if (Build.VERSION.SDK_INT >= 28) {
                return c.b(obj);
            }
            try {
                return (String) obj.getClass().getMethod("getResPackage", new Class[0]).invoke(obj, new Object[0]);
            } catch (IllegalAccessException e3) {
                Log.e("IconCompat", "Unable to get icon package", e3);
                return null;
            } catch (NoSuchMethodException e4) {
                Log.e("IconCompat", "Unable to get icon package", e4);
                return null;
            } catch (InvocationTargetException e5) {
                Log.e("IconCompat", "Unable to get icon package", e5);
                return null;
            }
        }

        static Uri c(Object obj) {
            if (Build.VERSION.SDK_INT >= 28) {
                return c.d(obj);
            }
            try {
                return (Uri) obj.getClass().getMethod("getUri", new Class[0]).invoke(obj, new Object[0]);
            } catch (IllegalAccessException e3) {
                Log.e("IconCompat", "Unable to get icon uri", e3);
                return null;
            } catch (NoSuchMethodException e4) {
                Log.e("IconCompat", "Unable to get icon uri", e4);
                return null;
            } catch (InvocationTargetException e5) {
                Log.e("IconCompat", "Unable to get icon uri", e5);
                return null;
            }
        }

        static Drawable d(Icon icon, Context context) {
            return icon.loadDrawable(context);
        }

        /* JADX WARN: Code restructure failed: missing block: B:13:0x002c, code lost:
            if (r0 >= 26) goto L23;
         */
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        static Icon e(IconCompat iconCompat, Context context) {
            Bitmap bitmap;
            Icon createWithResource;
            Bitmap bitmap2;
            switch (iconCompat.f1515a) {
                case androidx.swiperefreshlayout.widget.c.DEFAULT_SLINGSHOT_DISTANCE /* -1 */:
                    return (Icon) iconCompat.f1516b;
                case 0:
                default:
                    throw new IllegalArgumentException("Unknown type");
                case 1:
                    bitmap = (Bitmap) iconCompat.f1516b;
                    createWithResource = Icon.createWithBitmap(bitmap);
                    break;
                case 2:
                    createWithResource = Icon.createWithResource(iconCompat.c(), iconCompat.f1519e);
                    break;
                case 3:
                    createWithResource = Icon.createWithData((byte[]) iconCompat.f1516b, iconCompat.f1519e, iconCompat.f1520f);
                    break;
                case 4:
                    createWithResource = Icon.createWithContentUri((String) iconCompat.f1516b);
                    break;
                case 5:
                    if (Build.VERSION.SDK_INT < 26) {
                        bitmap2 = (Bitmap) iconCompat.f1516b;
                        bitmap = IconCompat.a(bitmap2, false);
                        createWithResource = Icon.createWithBitmap(bitmap);
                        break;
                    } else {
                        bitmap2 = (Bitmap) iconCompat.f1516b;
                        createWithResource = b.b(bitmap2);
                        break;
                    }
                case 6:
                    int i3 = Build.VERSION.SDK_INT;
                    if (i3 >= 30) {
                        createWithResource = d.a(iconCompat.d());
                        break;
                    } else if (context == null) {
                        throw new IllegalArgumentException("Context is required to resolve the file uri of the icon: " + iconCompat.d());
                    } else {
                        InputStream e3 = iconCompat.e(context);
                        if (e3 == null) {
                            throw new IllegalStateException("Cannot load adaptive icon from uri: " + iconCompat.d());
                        }
                        bitmap2 = BitmapFactory.decodeStream(e3);
                        break;
                    }
            }
            ColorStateList colorStateList = iconCompat.f1521g;
            if (colorStateList != null) {
                createWithResource.setTintList(colorStateList);
            }
            PorterDuff.Mode mode = iconCompat.f1522h;
            if (mode != IconCompat.f1514k) {
                createWithResource.setTintMode(mode);
            }
            return createWithResource;
        }
    }

    /* loaded from: classes.dex */
    static class b {
        static Drawable a(Drawable drawable, Drawable drawable2) {
            return new AdaptiveIconDrawable(drawable, drawable2);
        }

        static Icon b(Bitmap bitmap) {
            Icon createWithAdaptiveBitmap;
            createWithAdaptiveBitmap = Icon.createWithAdaptiveBitmap(bitmap);
            return createWithAdaptiveBitmap;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class c {
        static int a(Object obj) {
            int resId;
            resId = ((Icon) obj).getResId();
            return resId;
        }

        static String b(Object obj) {
            String resPackage;
            resPackage = ((Icon) obj).getResPackage();
            return resPackage;
        }

        static int c(Object obj) {
            int type;
            type = ((Icon) obj).getType();
            return type;
        }

        static Uri d(Object obj) {
            Uri uri;
            uri = ((Icon) obj).getUri();
            return uri;
        }
    }

    /* loaded from: classes.dex */
    static class d {
        static Icon a(Uri uri) {
            Icon createWithAdaptiveBitmapContentUri;
            createWithAdaptiveBitmapContentUri = Icon.createWithAdaptiveBitmapContentUri(uri);
            return createWithAdaptiveBitmapContentUri;
        }
    }

    static Bitmap a(Bitmap bitmap, boolean z2) {
        int min = (int) (Math.min(bitmap.getWidth(), bitmap.getHeight()) * 0.6666667f);
        Bitmap createBitmap = Bitmap.createBitmap(min, min, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap);
        Paint paint = new Paint(3);
        float f3 = min;
        float f4 = 0.5f * f3;
        float f5 = 0.9166667f * f4;
        if (z2) {
            float f6 = 0.010416667f * f3;
            paint.setColor(0);
            paint.setShadowLayer(f6, 0.0f, f3 * 0.020833334f, 1023410176);
            canvas.drawCircle(f4, f4, f5, paint);
            paint.setShadowLayer(f6, 0.0f, 0.0f, 503316480);
            canvas.drawCircle(f4, f4, f5, paint);
            paint.clearShadowLayer();
        }
        paint.setColor(-16777216);
        Shader.TileMode tileMode = Shader.TileMode.CLAMP;
        BitmapShader bitmapShader = new BitmapShader(bitmap, tileMode, tileMode);
        Matrix matrix = new Matrix();
        matrix.setTranslate((-(bitmap.getWidth() - min)) / 2.0f, (-(bitmap.getHeight() - min)) / 2.0f);
        bitmapShader.setLocalMatrix(matrix);
        paint.setShader(bitmapShader);
        canvas.drawCircle(f4, f4, f5, paint);
        canvas.setBitmap(null);
        return createBitmap;
    }

    private static String h(int i3) {
        switch (i3) {
            case 1:
                return "BITMAP";
            case 2:
                return "RESOURCE";
            case 3:
                return "DATA";
            case 4:
                return "URI";
            case 5:
                return "BITMAP_MASKABLE";
            case 6:
                return "URI_MASKABLE";
            default:
                return "UNKNOWN";
        }
    }

    public int b() {
        int i3 = this.f1515a;
        if (i3 != -1 || Build.VERSION.SDK_INT < 23) {
            if (i3 == 2) {
                return this.f1519e;
            }
            throw new IllegalStateException("called getResId() on " + this);
        }
        return a.a(this.f1516b);
    }

    public String c() {
        int i3 = this.f1515a;
        if (i3 != -1 || Build.VERSION.SDK_INT < 23) {
            if (i3 == 2) {
                String str = this.f1524j;
                return (str == null || TextUtils.isEmpty(str)) ? ((String) this.f1516b).split(":", -1)[0] : this.f1524j;
            }
            throw new IllegalStateException("called getResPackage() on " + this);
        }
        return a.b(this.f1516b);
    }

    public Uri d() {
        int i3 = this.f1515a;
        if (i3 != -1 || Build.VERSION.SDK_INT < 23) {
            if (i3 == 4 || i3 == 6) {
                return Uri.parse((String) this.f1516b);
            }
            throw new IllegalStateException("called getUri() on " + this);
        }
        return a.c(this.f1516b);
    }

    public InputStream e(Context context) {
        StringBuilder sb;
        String str;
        Uri d3 = d();
        String scheme = d3.getScheme();
        if ("content".equals(scheme) || "file".equals(scheme)) {
            try {
                return context.getContentResolver().openInputStream(d3);
            } catch (Exception e3) {
                e = e3;
                sb = new StringBuilder();
                str = "Unable to load image from URI: ";
            }
        } else {
            try {
                return new FileInputStream(new File((String) this.f1516b));
            } catch (FileNotFoundException e4) {
                e = e4;
                sb = new StringBuilder();
                str = "Unable to load image from path: ";
            }
        }
        sb.append(str);
        sb.append(d3);
        Log.w("IconCompat", sb.toString(), e);
        return null;
    }

    public void f() {
        Parcelable parcelable;
        this.f1522h = PorterDuff.Mode.valueOf(this.f1523i);
        switch (this.f1515a) {
            case androidx.swiperefreshlayout.widget.c.DEFAULT_SLINGSHOT_DISTANCE /* -1 */:
                parcelable = this.f1518d;
                if (parcelable == null) {
                    throw new IllegalArgumentException("Invalid icon");
                }
                break;
            case 0:
            default:
                return;
            case 1:
            case 5:
                parcelable = this.f1518d;
                if (parcelable == null) {
                    byte[] bArr = this.f1517c;
                    this.f1516b = bArr;
                    this.f1515a = 3;
                    this.f1519e = 0;
                    this.f1520f = bArr.length;
                    return;
                }
                break;
            case 2:
            case 4:
            case 6:
                String str = new String(this.f1517c, Charset.forName("UTF-16"));
                this.f1516b = str;
                if (this.f1515a == 2 && this.f1524j == null) {
                    this.f1524j = str.split(":", -1)[0];
                    return;
                }
                return;
            case 3:
                this.f1516b = this.f1517c;
                return;
        }
        this.f1516b = parcelable;
    }

    public void g(boolean z2) {
        this.f1523i = this.f1522h.name();
        switch (this.f1515a) {
            case androidx.swiperefreshlayout.widget.c.DEFAULT_SLINGSHOT_DISTANCE /* -1 */:
                if (z2) {
                    throw new IllegalArgumentException("Can't serialize Icon created with IconCompat#createFromIcon");
                }
                break;
            case 0:
            default:
                return;
            case 1:
            case 5:
                if (z2) {
                    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                    ((Bitmap) this.f1516b).compress(Bitmap.CompressFormat.PNG, 90, byteArrayOutputStream);
                    this.f1517c = byteArrayOutputStream.toByteArray();
                    return;
                }
                break;
            case 2:
                this.f1517c = ((String) this.f1516b).getBytes(Charset.forName("UTF-16"));
                return;
            case 3:
                this.f1517c = (byte[]) this.f1516b;
                return;
            case 4:
            case 6:
                this.f1517c = this.f1516b.toString().getBytes(Charset.forName("UTF-16"));
                return;
        }
        this.f1518d = (Parcelable) this.f1516b;
    }

    public String toString() {
        int height;
        if (this.f1515a == -1) {
            return String.valueOf(this.f1516b);
        }
        StringBuilder sb = new StringBuilder("Icon(typ=");
        sb.append(h(this.f1515a));
        switch (this.f1515a) {
            case 1:
            case 5:
                sb.append(" size=");
                sb.append(((Bitmap) this.f1516b).getWidth());
                sb.append("x");
                height = ((Bitmap) this.f1516b).getHeight();
                sb.append(height);
                break;
            case 2:
                sb.append(" pkg=");
                sb.append(this.f1524j);
                sb.append(" id=");
                sb.append(String.format("0x%08x", Integer.valueOf(b())));
                break;
            case 3:
                sb.append(" len=");
                sb.append(this.f1519e);
                if (this.f1520f != 0) {
                    sb.append(" off=");
                    height = this.f1520f;
                    sb.append(height);
                    break;
                }
                break;
            case 4:
            case 6:
                sb.append(" uri=");
                sb.append(this.f1516b);
                break;
        }
        if (this.f1521g != null) {
            sb.append(" tint=");
            sb.append(this.f1521g);
        }
        if (this.f1522h != f1514k) {
            sb.append(" mode=");
            sb.append(this.f1522h);
        }
        sb.append(")");
        return sb.toString();
    }
}
