package io.flutter.embedding.engine.renderer;

import android.graphics.Rect;
import android.graphics.SurfaceTexture;
import android.media.Image;
import android.media.ImageReader;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.view.Surface;
import androidx.lifecycle.o;
import androidx.lifecycle.z;
import io.flutter.embedding.engine.FlutterJNI;
import io.flutter.embedding.engine.renderer.FlutterRenderer;
import io.flutter.view.TextureRegistry;
import java.io.IOException;
import java.lang.ref.WeakReference;
import java.nio.ByteBuffer;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.concurrent.atomic.AtomicLong;
/* loaded from: classes.dex */
public class FlutterRenderer implements TextureRegistry {

    /* renamed from: m  reason: collision with root package name */
    public static boolean f3559m = false;

    /* renamed from: n  reason: collision with root package name */
    public static boolean f3560n = false;

    /* renamed from: e  reason: collision with root package name */
    private final FlutterJNI f3561e;

    /* renamed from: g  reason: collision with root package name */
    private Surface f3563g;

    /* renamed from: l  reason: collision with root package name */
    private final io.flutter.embedding.engine.renderer.d f3568l;

    /* renamed from: f  reason: collision with root package name */
    private final AtomicLong f3562f = new AtomicLong(0);

    /* renamed from: h  reason: collision with root package name */
    private boolean f3564h = false;

    /* renamed from: i  reason: collision with root package name */
    private final Handler f3565i = new Handler();

    /* renamed from: j  reason: collision with root package name */
    private final Set<WeakReference<TextureRegistry.b>> f3566j = new HashSet();

    /* renamed from: k  reason: collision with root package name */
    private final List<ImageReaderSurfaceProducer> f3567k = new ArrayList();

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public final class ImageReaderSurfaceProducer implements TextureRegistry.SurfaceProducer, TextureRegistry.ImageConsumer, TextureRegistry.b {
        private static final boolean CLEANUP_ON_MEMORY_PRESSURE = true;
        private static final int MAX_IMAGES = 5;
        private static final String TAG = "ImageReaderSurfaceProducer";
        private static final boolean VERBOSE_LOGS = false;
        private static final boolean trimOnMemoryPressure = true;
        private final long id;
        private boolean released;
        private boolean ignoringFence = false;
        private int requestedWidth = 1;
        private int requestedHeight = 1;
        private boolean createNewReader = true;
        private long lastDequeueTime = 0;
        private long lastQueueTime = 0;
        private long lastScheduleTime = 0;
        private int numTrims = 0;
        private final Object lock = new Object();
        private final ArrayDeque<b> imageReaderQueue = new ArrayDeque<>();
        private final HashMap<ImageReader, b> perImageReaders = new HashMap<>();
        private a lastDequeuedImage = null;
        private b lastReaderDequeuedFrom = null;
        private TextureRegistry.SurfaceProducer.a callback = null;

        /* JADX INFO: Access modifiers changed from: private */
        /* loaded from: classes.dex */
        public class a {

            /* renamed from: a  reason: collision with root package name */
            public final Image f3569a;

            /* renamed from: b  reason: collision with root package name */
            public final long f3570b;

            public a(Image image, long j3) {
                this.f3569a = image;
                this.f3570b = j3;
            }
        }

        /* JADX INFO: Access modifiers changed from: private */
        /* loaded from: classes.dex */
        public class b {

            /* renamed from: a  reason: collision with root package name */
            public final ImageReader f3572a;

            /* renamed from: b  reason: collision with root package name */
            private final ArrayDeque<a> f3573b = new ArrayDeque<>();

            /* renamed from: c  reason: collision with root package name */
            private boolean f3574c = false;

            public b(ImageReader imageReader) {
                this.f3572a = imageReader;
                imageReader.setOnImageAvailableListener(new ImageReader.OnImageAvailableListener() { // from class: io.flutter.embedding.engine.renderer.a
                    @Override // android.media.ImageReader.OnImageAvailableListener
                    public final void onImageAvailable(ImageReader imageReader2) {
                        FlutterRenderer.ImageReaderSurfaceProducer.b.this.f(imageReader2);
                    }
                }, new Handler(Looper.getMainLooper()));
            }

            /* JADX INFO: Access modifiers changed from: private */
            public /* synthetic */ void f(ImageReader imageReader) {
                Image image;
                try {
                    image = imageReader.acquireLatestImage();
                } catch (IllegalStateException e3) {
                    d1.b.b(ImageReaderSurfaceProducer.TAG, "onImageAvailable acquireLatestImage failed: " + e3);
                    image = null;
                }
                if (image == null) {
                    return;
                }
                if (ImageReaderSurfaceProducer.this.released || this.f3574c) {
                    image.close();
                } else {
                    ImageReaderSurfaceProducer.this.onImage(imageReader, image);
                }
            }

            boolean c() {
                return this.f3573b.isEmpty() && ImageReaderSurfaceProducer.this.lastReaderDequeuedFrom != this;
            }

            void d() {
                this.f3574c = true;
                this.f3572a.close();
                this.f3573b.clear();
            }

            a e() {
                if (this.f3573b.isEmpty()) {
                    return null;
                }
                return this.f3573b.removeFirst();
            }

            a g(Image image) {
                if (this.f3574c) {
                    return null;
                }
                a aVar = new a(image, System.nanoTime());
                this.f3573b.add(aVar);
                while (this.f3573b.size() > 2) {
                    this.f3573b.removeFirst().f3569a.close();
                }
                return aVar;
            }
        }

        ImageReaderSurfaceProducer(long j3) {
            this.id = j3;
        }

        private void cleanup() {
            synchronized (this.lock) {
                for (b bVar : this.perImageReaders.values()) {
                    if (this.lastReaderDequeuedFrom == bVar) {
                        this.lastReaderDequeuedFrom = null;
                    }
                    bVar.d();
                }
                this.perImageReaders.clear();
                a aVar = this.lastDequeuedImage;
                if (aVar != null) {
                    aVar.f3569a.close();
                    this.lastDequeuedImage = null;
                }
                b bVar2 = this.lastReaderDequeuedFrom;
                if (bVar2 != null) {
                    bVar2.d();
                    this.lastReaderDequeuedFrom = null;
                }
                this.imageReaderQueue.clear();
            }
        }

        private ImageReader createImageReader() {
            int i3 = Build.VERSION.SDK_INT;
            if (i3 >= 33) {
                return createImageReader33();
            }
            if (i3 >= 29) {
                return createImageReader29();
            }
            throw new UnsupportedOperationException("ImageReaderPlatformViewRenderTarget requires API version 29+");
        }

        private ImageReader createImageReader29() {
            ImageReader newInstance;
            newInstance = ImageReader.newInstance(this.requestedWidth, this.requestedHeight, 34, 5, 256L);
            return newInstance;
        }

        private ImageReader createImageReader33() {
            ImageReader.Builder builder = new ImageReader.Builder(this.requestedWidth, this.requestedHeight);
            builder.setMaxImages(5);
            builder.setImageFormat(34);
            builder.setUsage(256L);
            return builder.build();
        }

        private b getActiveReader() {
            synchronized (this.lock) {
                if (!this.createNewReader) {
                    return this.imageReaderQueue.peekLast();
                }
                this.createNewReader = false;
                return getOrCreatePerImageReader(createImageReader());
            }
        }

        private void maybeWaitOnFence(Image image) {
            if (image == null || this.ignoringFence) {
                return;
            }
            if (Build.VERSION.SDK_INT >= 33) {
                waitOnFence(image);
                return;
            }
            this.ignoringFence = true;
            d1.b.a(TAG, "ImageTextureEntry can't wait on the fence on Android < 33");
        }

        private void releaseInternal() {
            cleanup();
            this.released = true;
            FlutterRenderer.this.f3567k.remove(this);
        }

        private void waitOnFence(Image image) {
            try {
                image.getFence().awaitForever();
            } catch (IOException unused) {
            }
        }

        @Override // io.flutter.view.TextureRegistry.ImageConsumer
        public Image acquireLatestImage() {
            a dequeueImage = dequeueImage();
            if (dequeueImage == null) {
                return null;
            }
            maybeWaitOnFence(dequeueImage.f3569a);
            return dequeueImage.f3569a;
        }

        double deltaMillis(long j3) {
            return j3 / 1000000.0d;
        }

        a dequeueImage() {
            a aVar;
            synchronized (this.lock) {
                Iterator<b> it = this.imageReaderQueue.iterator();
                aVar = null;
                while (true) {
                    if (!it.hasNext()) {
                        break;
                    }
                    b next = it.next();
                    a e3 = next.e();
                    if (e3 == null) {
                        aVar = e3;
                    } else {
                        a aVar2 = this.lastDequeuedImage;
                        if (aVar2 != null) {
                            aVar2.f3569a.close();
                        }
                        this.lastDequeuedImage = e3;
                        this.lastReaderDequeuedFrom = next;
                        aVar = e3;
                    }
                }
                pruneImageReaderQueue();
            }
            return aVar;
        }

        public void disableFenceForTest() {
            this.ignoringFence = true;
        }

        protected void finalize() {
            try {
                if (this.released) {
                    return;
                }
                releaseInternal();
                FlutterRenderer.this.f3565i.post(new g(this.id, FlutterRenderer.this.f3561e));
            } finally {
                super.finalize();
            }
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceProducer
        public int getHeight() {
            return this.requestedHeight;
        }

        b getOrCreatePerImageReader(ImageReader imageReader) {
            b bVar = this.perImageReaders.get(imageReader);
            if (bVar == null) {
                b bVar2 = new b(imageReader);
                this.perImageReaders.put(imageReader, bVar2);
                this.imageReaderQueue.add(bVar2);
                return bVar2;
            }
            return bVar;
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceProducer
        public Surface getSurface() {
            return getActiveReader().f3572a.getSurface();
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceProducer
        public int getWidth() {
            return this.requestedWidth;
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceProducer
        public long id() {
            return this.id;
        }

        public int numImageReaders() {
            int size;
            synchronized (this.lock) {
                size = this.imageReaderQueue.size();
            }
            return size;
        }

        public int numImages() {
            int i3;
            synchronized (this.lock) {
                Iterator<b> it = this.imageReaderQueue.iterator();
                i3 = 0;
                while (it.hasNext()) {
                    i3 += it.next().f3573b.size();
                }
            }
            return i3;
        }

        public int numTrims() {
            int i3;
            synchronized (this.lock) {
                i3 = this.numTrims;
            }
            return i3;
        }

        void onImage(ImageReader imageReader, Image image) {
            a g3;
            synchronized (this.lock) {
                g3 = getOrCreatePerImageReader(imageReader).g(image);
            }
            if (g3 == null) {
                return;
            }
            FlutterRenderer.this.w();
        }

        @Override // io.flutter.view.TextureRegistry.b
        public void onTrimMemory(int i3) {
            if (i3 < 40) {
                return;
            }
            synchronized (this.lock) {
                this.numTrims++;
            }
            cleanup();
            this.createNewReader = true;
            TextureRegistry.SurfaceProducer.a aVar = this.callback;
            if (aVar != null) {
                aVar.b();
            }
        }

        void pruneImageReaderQueue() {
            b peekFirst;
            while (this.imageReaderQueue.size() > 1 && (peekFirst = this.imageReaderQueue.peekFirst()) != null && peekFirst.c()) {
                this.imageReaderQueue.removeFirst();
                this.perImageReaders.remove(peekFirst.f3572a);
                peekFirst.d();
            }
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceProducer
        public void release() {
            if (this.released) {
                return;
            }
            releaseInternal();
            FlutterRenderer.this.D(this.id);
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceProducer
        public void scheduleFrame() {
            FlutterRenderer.this.w();
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceProducer
        public void setCallback(TextureRegistry.SurfaceProducer.a aVar) {
            this.callback = aVar;
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceProducer
        public void setSize(int i3, int i4) {
            int max = Math.max(1, i3);
            int max2 = Math.max(1, i4);
            if (this.requestedWidth == max && this.requestedHeight == max2) {
                return;
            }
            this.createNewReader = true;
            this.requestedHeight = max2;
            this.requestedWidth = max;
        }
    }

    /* loaded from: classes.dex */
    final class ImageTextureRegistryEntry implements TextureRegistry.ImageTextureEntry, TextureRegistry.ImageConsumer {
        private static final String TAG = "ImageTextureRegistryEntry";
        private final long id;
        private boolean ignoringFence = false;
        private Image image;
        private boolean released;

        ImageTextureRegistryEntry(long j3) {
            this.id = j3;
        }

        private void maybeWaitOnFence(Image image) {
            if (image == null || this.ignoringFence) {
                return;
            }
            if (Build.VERSION.SDK_INT >= 33) {
                waitOnFence(image);
                return;
            }
            this.ignoringFence = true;
            d1.b.a(TAG, "ImageTextureEntry can't wait on the fence on Android < 33");
        }

        private void waitOnFence(Image image) {
            try {
                image.getFence().awaitForever();
            } catch (IOException unused) {
            }
        }

        @Override // io.flutter.view.TextureRegistry.ImageConsumer
        public Image acquireLatestImage() {
            Image image;
            synchronized (this) {
                image = this.image;
                this.image = null;
            }
            maybeWaitOnFence(image);
            return image;
        }

        protected void finalize() {
            try {
                if (this.released) {
                    return;
                }
                Image image = this.image;
                if (image != null) {
                    image.close();
                    this.image = null;
                }
                this.released = true;
                FlutterRenderer.this.f3565i.post(new g(this.id, FlutterRenderer.this.f3561e));
            } finally {
                super.finalize();
            }
        }

        @Override // io.flutter.view.TextureRegistry.ImageTextureEntry
        public long id() {
            return this.id;
        }

        @Override // io.flutter.view.TextureRegistry.ImageTextureEntry
        public void pushImage(Image image) {
            Image image2;
            if (this.released) {
                return;
            }
            synchronized (this) {
                image2 = this.image;
                this.image = image;
            }
            if (image2 != null) {
                d1.b.b(TAG, "Dropping PlatformView Frame");
                image2.close();
            }
            if (image != null) {
                FlutterRenderer.this.w();
            }
        }

        @Override // io.flutter.view.TextureRegistry.ImageTextureEntry
        public void release() {
            if (this.released) {
                return;
            }
            this.released = true;
            Image image = this.image;
            if (image != null) {
                image.close();
                this.image = null;
            }
            FlutterRenderer.this.D(this.id);
        }
    }

    /* loaded from: classes.dex */
    class a implements io.flutter.embedding.engine.renderer.d {
        a() {
        }

        @Override // io.flutter.embedding.engine.renderer.d
        public void b() {
            FlutterRenderer.this.f3564h = false;
        }

        @Override // io.flutter.embedding.engine.renderer.d
        public void d() {
            FlutterRenderer.this.f3564h = true;
        }
    }

    /* loaded from: classes.dex */
    class b implements androidx.lifecycle.e {
        b() {
        }

        @Override // androidx.lifecycle.e
        public void a(o oVar) {
            d1.b.f("FlutterRenderer", "onResume called; notifying SurfaceProducers");
            for (ImageReaderSurfaceProducer imageReaderSurfaceProducer : FlutterRenderer.this.f3567k) {
                if (imageReaderSurfaceProducer.callback != null) {
                    imageReaderSurfaceProducer.callback.a();
                }
            }
        }

        @Override // androidx.lifecycle.e
        public /* synthetic */ void b(o oVar) {
            androidx.lifecycle.d.b(this, oVar);
        }

        @Override // androidx.lifecycle.e
        public /* synthetic */ void c(o oVar) {
            androidx.lifecycle.d.a(this, oVar);
        }

        @Override // androidx.lifecycle.e
        public /* synthetic */ void e(o oVar) {
            androidx.lifecycle.d.c(this, oVar);
        }

        @Override // androidx.lifecycle.e
        public /* synthetic */ void f(o oVar) {
            androidx.lifecycle.d.d(this, oVar);
        }

        @Override // androidx.lifecycle.e
        public /* synthetic */ void g(o oVar) {
            androidx.lifecycle.d.e(this, oVar);
        }
    }

    /* loaded from: classes.dex */
    public static final class c {

        /* renamed from: a  reason: collision with root package name */
        public final Rect f3578a;

        /* renamed from: b  reason: collision with root package name */
        public final e f3579b;

        /* renamed from: c  reason: collision with root package name */
        public final d f3580c;

        public c(Rect rect, e eVar) {
            this.f3578a = rect;
            this.f3579b = eVar;
            this.f3580c = d.UNKNOWN;
        }

        public c(Rect rect, e eVar, d dVar) {
            this.f3578a = rect;
            this.f3579b = eVar;
            this.f3580c = dVar;
        }
    }

    /* loaded from: classes.dex */
    public enum d {
        UNKNOWN(0),
        POSTURE_FLAT(1),
        POSTURE_HALF_OPENED(2);
        

        /* renamed from: e  reason: collision with root package name */
        public final int f3585e;

        d(int i3) {
            this.f3585e = i3;
        }
    }

    /* loaded from: classes.dex */
    public enum e {
        UNKNOWN(0),
        FOLD(1),
        HINGE(2),
        CUTOUT(3);
        

        /* renamed from: e  reason: collision with root package name */
        public final int f3591e;

        e(int i3) {
            this.f3591e = i3;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public final class f implements TextureRegistry.SurfaceTextureEntry, TextureRegistry.b {

        /* renamed from: a  reason: collision with root package name */
        private final long f3592a;

        /* renamed from: b  reason: collision with root package name */
        private final SurfaceTextureWrapper f3593b;

        /* renamed from: c  reason: collision with root package name */
        private boolean f3594c;

        /* renamed from: d  reason: collision with root package name */
        private TextureRegistry.b f3595d;

        /* renamed from: e  reason: collision with root package name */
        private TextureRegistry.a f3596e;

        f(long j3, SurfaceTexture surfaceTexture) {
            this.f3592a = j3;
            this.f3593b = new SurfaceTextureWrapper(surfaceTexture, new Runnable() { // from class: io.flutter.embedding.engine.renderer.b
                @Override // java.lang.Runnable
                public final void run() {
                    FlutterRenderer.f.this.c();
                }
            });
            surfaceTexture().setOnFrameAvailableListener(new SurfaceTexture.OnFrameAvailableListener() { // from class: io.flutter.embedding.engine.renderer.c
                @Override // android.graphics.SurfaceTexture.OnFrameAvailableListener
                public final void onFrameAvailable(SurfaceTexture surfaceTexture2) {
                    FlutterRenderer.f.this.d(surfaceTexture2);
                }
            }, new Handler());
        }

        /* JADX INFO: Access modifiers changed from: private */
        public /* synthetic */ void c() {
            TextureRegistry.a aVar = this.f3596e;
            if (aVar != null) {
                aVar.a();
            }
        }

        /* JADX INFO: Access modifiers changed from: private */
        public /* synthetic */ void d(SurfaceTexture surfaceTexture) {
            if (this.f3594c || !FlutterRenderer.this.f3561e.isAttached()) {
                return;
            }
            this.f3593b.markDirty();
            FlutterRenderer.this.w();
        }

        private void e() {
            FlutterRenderer.this.v(this);
        }

        public SurfaceTextureWrapper f() {
            return this.f3593b;
        }

        protected void finalize() {
            try {
                if (this.f3594c) {
                    return;
                }
                FlutterRenderer.this.f3565i.post(new g(this.f3592a, FlutterRenderer.this.f3561e));
            } finally {
                super.finalize();
            }
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceTextureEntry
        public long id() {
            return this.f3592a;
        }

        @Override // io.flutter.view.TextureRegistry.b
        public void onTrimMemory(int i3) {
            TextureRegistry.b bVar = this.f3595d;
            if (bVar != null) {
                bVar.onTrimMemory(i3);
            }
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceTextureEntry
        public void release() {
            if (this.f3594c) {
                return;
            }
            d1.b.f("FlutterRenderer", "Releasing a SurfaceTexture (" + this.f3592a + ").");
            this.f3593b.release();
            FlutterRenderer.this.D(this.f3592a);
            e();
            this.f3594c = true;
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceTextureEntry
        public void setOnFrameConsumedListener(TextureRegistry.a aVar) {
            this.f3596e = aVar;
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceTextureEntry
        public void setOnTrimMemoryListener(TextureRegistry.b bVar) {
            this.f3595d = bVar;
        }

        @Override // io.flutter.view.TextureRegistry.SurfaceTextureEntry
        public SurfaceTexture surfaceTexture() {
            return this.f3593b.surfaceTexture();
        }
    }

    /* loaded from: classes.dex */
    static final class g implements Runnable {

        /* renamed from: e  reason: collision with root package name */
        private final long f3598e;

        /* renamed from: f  reason: collision with root package name */
        private final FlutterJNI f3599f;

        /* JADX INFO: Access modifiers changed from: package-private */
        public g(long j3, FlutterJNI flutterJNI) {
            this.f3598e = j3;
            this.f3599f = flutterJNI;
        }

        @Override // java.lang.Runnable
        public void run() {
            if (this.f3599f.isAttached()) {
                d1.b.f("FlutterRenderer", "Releasing a Texture (" + this.f3598e + ").");
                this.f3599f.unregisterTexture(this.f3598e);
            }
        }
    }

    /* loaded from: classes.dex */
    public static final class h {

        /* renamed from: a  reason: collision with root package name */
        public float f3600a = 1.0f;

        /* renamed from: b  reason: collision with root package name */
        public int f3601b = 0;

        /* renamed from: c  reason: collision with root package name */
        public int f3602c = 0;

        /* renamed from: d  reason: collision with root package name */
        public int f3603d = 0;

        /* renamed from: e  reason: collision with root package name */
        public int f3604e = 0;

        /* renamed from: f  reason: collision with root package name */
        public int f3605f = 0;

        /* renamed from: g  reason: collision with root package name */
        public int f3606g = 0;

        /* renamed from: h  reason: collision with root package name */
        public int f3607h = 0;

        /* renamed from: i  reason: collision with root package name */
        public int f3608i = 0;

        /* renamed from: j  reason: collision with root package name */
        public int f3609j = 0;

        /* renamed from: k  reason: collision with root package name */
        public int f3610k = 0;

        /* renamed from: l  reason: collision with root package name */
        public int f3611l = 0;

        /* renamed from: m  reason: collision with root package name */
        public int f3612m = 0;

        /* renamed from: n  reason: collision with root package name */
        public int f3613n = 0;

        /* renamed from: o  reason: collision with root package name */
        public int f3614o = 0;

        /* renamed from: p  reason: collision with root package name */
        public int f3615p = -1;

        /* renamed from: q  reason: collision with root package name */
        public List<c> f3616q = new ArrayList();

        boolean a() {
            return this.f3601b > 0 && this.f3602c > 0 && this.f3600a > 0.0f;
        }
    }

    public FlutterRenderer(FlutterJNI flutterJNI) {
        a aVar = new a();
        this.f3568l = aVar;
        this.f3561e = flutterJNI;
        flutterJNI.addIsDisplayingFlutterUiListener(aVar);
        z.l().getLifecycle().a(new b());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void D(long j3) {
        this.f3561e.unregisterTexture(j3);
    }

    private void l() {
        Iterator<WeakReference<TextureRegistry.b>> it = this.f3566j.iterator();
        while (it.hasNext()) {
            if (it.next().get() == null) {
                it.remove();
            }
        }
    }

    private void q(long j3, TextureRegistry.ImageConsumer imageConsumer) {
        this.f3561e.registerImageTexture(j3, imageConsumer);
    }

    private TextureRegistry.SurfaceTextureEntry r(long j3, SurfaceTexture surfaceTexture) {
        surfaceTexture.detachFromGLContext();
        f fVar = new f(j3, surfaceTexture);
        d1.b.f("FlutterRenderer", "New SurfaceTexture ID: " + fVar.id());
        t(fVar.id(), fVar.f());
        k(fVar);
        return fVar;
    }

    private void t(long j3, SurfaceTextureWrapper surfaceTextureWrapper) {
        this.f3561e.registerTexture(j3, surfaceTextureWrapper);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void w() {
        this.f3561e.scheduleFrame();
    }

    public void A() {
        if (this.f3563g != null) {
            this.f3561e.onSurfaceDestroyed();
            if (this.f3564h) {
                this.f3568l.b();
            }
            this.f3564h = false;
            this.f3563g = null;
        }
    }

    public void B(int i3, int i4) {
        this.f3561e.onSurfaceChanged(i3, i4);
    }

    public void C(Surface surface) {
        this.f3563g = surface;
        this.f3561e.onSurfaceWindowChanged(surface);
    }

    @Override // io.flutter.view.TextureRegistry
    public TextureRegistry.ImageTextureEntry c() {
        ImageTextureRegistryEntry imageTextureRegistryEntry = new ImageTextureRegistryEntry(this.f3562f.getAndIncrement());
        d1.b.f("FlutterRenderer", "New ImageTextureEntry ID: " + imageTextureRegistryEntry.id());
        q(imageTextureRegistryEntry.id(), imageTextureRegistryEntry);
        return imageTextureRegistryEntry;
    }

    @Override // io.flutter.view.TextureRegistry
    public TextureRegistry.SurfaceProducer g() {
        if (f3559m || Build.VERSION.SDK_INT < 29) {
            TextureRegistry.SurfaceTextureEntry j3 = j();
            io.flutter.embedding.engine.renderer.f fVar = new io.flutter.embedding.engine.renderer.f(j3.id(), this.f3565i, this.f3561e, j3);
            d1.b.f("FlutterRenderer", "New SurfaceTextureSurfaceProducer ID: " + j3.id());
            return fVar;
        }
        long andIncrement = this.f3562f.getAndIncrement();
        ImageReaderSurfaceProducer imageReaderSurfaceProducer = new ImageReaderSurfaceProducer(andIncrement);
        q(andIncrement, imageReaderSurfaceProducer);
        k(imageReaderSurfaceProducer);
        this.f3567k.add(imageReaderSurfaceProducer);
        d1.b.f("FlutterRenderer", "New ImageReaderSurfaceProducer ID: " + andIncrement);
        return imageReaderSurfaceProducer;
    }

    public void i(io.flutter.embedding.engine.renderer.d dVar) {
        this.f3561e.addIsDisplayingFlutterUiListener(dVar);
        if (this.f3564h) {
            dVar.d();
        }
    }

    @Override // io.flutter.view.TextureRegistry
    public TextureRegistry.SurfaceTextureEntry j() {
        d1.b.f("FlutterRenderer", "Creating a SurfaceTexture.");
        return s(new SurfaceTexture(0));
    }

    void k(TextureRegistry.b bVar) {
        l();
        this.f3566j.add(new WeakReference<>(bVar));
    }

    public void m(ByteBuffer byteBuffer, int i3) {
        this.f3561e.dispatchPointerDataPacket(byteBuffer, i3);
    }

    public boolean n() {
        return this.f3564h;
    }

    public boolean o() {
        return this.f3561e.getIsSoftwareRenderingEnabled();
    }

    public void p(int i3) {
        Iterator<WeakReference<TextureRegistry.b>> it = this.f3566j.iterator();
        while (it.hasNext()) {
            TextureRegistry.b bVar = it.next().get();
            if (bVar != null) {
                bVar.onTrimMemory(i3);
            } else {
                it.remove();
            }
        }
    }

    public TextureRegistry.SurfaceTextureEntry s(SurfaceTexture surfaceTexture) {
        return r(this.f3562f.getAndIncrement(), surfaceTexture);
    }

    public void u(io.flutter.embedding.engine.renderer.d dVar) {
        this.f3561e.removeIsDisplayingFlutterUiListener(dVar);
    }

    void v(TextureRegistry.b bVar) {
        for (WeakReference<TextureRegistry.b> weakReference : this.f3566j) {
            if (weakReference.get() == bVar) {
                this.f3566j.remove(weakReference);
                return;
            }
        }
    }

    public void x(boolean z2) {
        this.f3561e.setSemanticsEnabled(z2);
    }

    public void y(h hVar) {
        if (hVar.a()) {
            d1.b.f("FlutterRenderer", "Setting viewport metrics\nSize: " + hVar.f3601b + " x " + hVar.f3602c + "\nPadding - L: " + hVar.f3606g + ", T: " + hVar.f3603d + ", R: " + hVar.f3604e + ", B: " + hVar.f3605f + "\nInsets - L: " + hVar.f3610k + ", T: " + hVar.f3607h + ", R: " + hVar.f3608i + ", B: " + hVar.f3609j + "\nSystem Gesture Insets - L: " + hVar.f3614o + ", T: " + hVar.f3611l + ", R: " + hVar.f3612m + ", B: " + hVar.f3612m + "\nDisplay Features: " + hVar.f3616q.size());
            int[] iArr = new int[hVar.f3616q.size() * 4];
            int[] iArr2 = new int[hVar.f3616q.size()];
            int[] iArr3 = new int[hVar.f3616q.size()];
            for (int i3 = 0; i3 < hVar.f3616q.size(); i3++) {
                c cVar = hVar.f3616q.get(i3);
                int i4 = i3 * 4;
                Rect rect = cVar.f3578a;
                iArr[i4] = rect.left;
                iArr[i4 + 1] = rect.top;
                iArr[i4 + 2] = rect.right;
                iArr[i4 + 3] = rect.bottom;
                iArr2[i3] = cVar.f3579b.f3591e;
                iArr3[i3] = cVar.f3580c.f3585e;
            }
            this.f3561e.setViewportMetrics(hVar.f3600a, hVar.f3601b, hVar.f3602c, hVar.f3603d, hVar.f3604e, hVar.f3605f, hVar.f3606g, hVar.f3607h, hVar.f3608i, hVar.f3609j, hVar.f3610k, hVar.f3611l, hVar.f3612m, hVar.f3613n, hVar.f3614o, hVar.f3615p, iArr, iArr2, iArr3);
        }
    }

    public void z(Surface surface, boolean z2) {
        if (!z2) {
            A();
        }
        this.f3563g = surface;
        if (z2) {
            this.f3561e.onSurfaceWindowChanged(surface);
        } else {
            this.f3561e.onSurfaceCreated(surface);
        }
    }
}
